
From: Ian Campbell <icampbell@arcom.com>

The attached patch causes the various arch specific install.sh scripts to
look for ${CROSS_COMPILE}installkernel rather than just installkernel (in
both /sbin/ and ~/bin/ where the script already did this).  This allows you
to have e.g.  arm-linux-installkernel as a handy way to install on your
cross target.  It also prevents the script picking up on the host
/sbin/installkernel which causes the script to fall through and do the
install itself (which is what I actually use myself, with $INSTALL_PATH
set).

I don't believe it causes back-compatibility problems since calling the
host installkernel was never likely to work or be what you wanted when
cross compiling anyway.  If $CROSS_COMPILE isn't set then nothing changes.

I only use ARM and i386 myself but I figured it couldn't hurt to do the
whole lot.  I've cc'd those who I hope are the arch maintainers for files
that I've touched.

Signed-off-by: Ian Campbell <icampbell@arcom.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/arm/boot/install.sh    |    4 ++--
 25-akpm/arch/arm26/boot/install.sh  |    4 ++--
 25-akpm/arch/i386/boot/install.sh   |    4 ++--
 25-akpm/arch/ppc64/boot/install.sh  |    4 ++--
 25-akpm/arch/s390/boot/install.sh   |    4 ++--
 25-akpm/arch/x86_64/boot/install.sh |    4 ++--
 6 files changed, 12 insertions(+), 12 deletions(-)

diff -puN arch/arm26/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh arch/arm26/boot/install.sh
--- 25/arch/arm26/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh	Wed Mar 30 15:37:02 2005
+++ 25-akpm/arch/arm26/boot/install.sh	Wed Mar 30 15:37:02 2005
@@ -23,8 +23,8 @@
 
 # User may have a custom install script
 
-if [ -x /sbin/installkernel ]; then
-  exec /sbin/installkernel "$@"
+if [ -x /sbin/${CROSS_COMPILE}installkernel ]; then
+  exec /sbin/${CROSS_COMPILE}installkernel "$@"
 fi
 
 if [ "$2" = "zImage" ]; then
diff -puN arch/arm/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh arch/arm/boot/install.sh
--- 25/arch/arm/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh	Wed Mar 30 15:37:02 2005
+++ 25-akpm/arch/arm/boot/install.sh	Wed Mar 30 15:37:02 2005
@@ -21,8 +21,8 @@
 #
 
 # User may have a custom install script
-if [ -x ~/bin/installkernel ]; then exec ~/bin/installkernel "$@"; fi
-if [ -x /sbin/installkernel ]; then exec /sbin/installkernel "$@"; fi
+if [ -x ~/bin/${CROSS_COMPILE}installkernel ]; then exec ~/bin/${CROSS_COMPILE}installkernel "$@"; fi
+if [ -x /sbin/${CROSS_COMPILE}installkernel ]; then exec /sbin/${CROSS_COMPILE}installkernel "$@"; fi
 
 if [ "$(basename $2)" = "zImage" ]; then
 # Compressed install
diff -puN arch/i386/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh arch/i386/boot/install.sh
--- 25/arch/i386/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh	Wed Mar 30 15:37:02 2005
+++ 25-akpm/arch/i386/boot/install.sh	Wed Mar 30 15:37:02 2005
@@ -21,8 +21,8 @@
 
 # User may have a custom install script
 
-if [ -x ~/bin/installkernel ]; then exec ~/bin/installkernel "$@"; fi
-if [ -x /sbin/installkernel ]; then exec /sbin/installkernel "$@"; fi
+if [ -x ~/bin/${CROSS_COMPILE}installkernel ]; then exec ~/bin/${CROSS_COMPILE}installkernel "$@"; fi
+if [ -x /sbin/${CROSS_COMPILE}installkernel ]; then exec /sbin/${CROSS_COMPILE}installkernel "$@"; fi
 
 # Default install - same as make zlilo
 
diff -puN arch/ppc64/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh arch/ppc64/boot/install.sh
--- 25/arch/ppc64/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh	Wed Mar 30 15:37:02 2005
+++ 25-akpm/arch/ppc64/boot/install.sh	Wed Mar 30 15:37:02 2005
@@ -22,8 +22,8 @@
 
 # User may have a custom install script
 
-if [ -x ~/bin/installkernel ]; then exec ~/bin/installkernel "$@"; fi
-if [ -x /sbin/installkernel ]; then exec /sbin/installkernel "$@"; fi
+if [ -x ~/bin/${CROSS_COMPILE}installkernel ]; then exec ~/bin/${CROSS_COMPILE}installkernel "$@"; fi
+if [ -x /sbin/${CROSS_COMPILE}installkernel ]; then exec /sbin/${CROSS_COMPILE}installkernel "$@"; fi
 
 # Default install
 
diff -puN arch/s390/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh arch/s390/boot/install.sh
--- 25/arch/s390/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh	Wed Mar 30 15:37:02 2005
+++ 25-akpm/arch/s390/boot/install.sh	Wed Mar 30 15:37:02 2005
@@ -21,8 +21,8 @@
 
 # User may have a custom install script
 
-if [ -x ~/bin/installkernel ]; then exec ~/bin/installkernel "$@"; fi
-if [ -x /sbin/installkernel ]; then exec /sbin/installkernel "$@"; fi
+if [ -x ~/bin/${CROSS_COMPILE}installkernel ]; then exec ~/bin/${CROSS_COMPILE}installkernel "$@"; fi
+if [ -x /sbin/${CROSS_COMPILE}installkernel ]; then exec /sbin/${CROSS_COMPILE}installkernel "$@"; fi
 
 # Default install - same as make zlilo
 
diff -puN arch/x86_64/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh arch/x86_64/boot/install.sh
--- 25/arch/x86_64/boot/install.sh~use-cross_compileinstallkernel-in-arch-boot-installsh	Wed Mar 30 15:37:02 2005
+++ 25-akpm/arch/x86_64/boot/install.sh	Wed Mar 30 15:37:02 2005
@@ -21,8 +21,8 @@
 
 # User may have a custom install script
 
-if [ -x ~/bin/installkernel ]; then exec ~/bin/installkernel "$@"; fi
-if [ -x /sbin/installkernel ]; then exec /sbin/installkernel "$@"; fi
+if [ -x ~/bin/${CROSS_COMPILE}installkernel ]; then exec ~/bin/${CROSS_COMPILE}installkernel "$@"; fi
+if [ -x /sbin/${CROSS_COMPILE}installkernel ]; then exec /sbin/${CROSS_COMPILE}installkernel "$@"; fi
 
 # Default install - same as make zlilo
 
_
